#! /bin/sh
#+
#
# NAME
# ====
#
# cat_clim_olr.sh - build OLR climatology file
#
# SYNOPSYS
# ========
#
# ``cat_clim_olr.sh``
#
#
# DESCRIPTION
# ===========
#
# Build OLR climatology file
# using mean daily file by year and reduce geographical domain
# to [60  W, 50  E] [30  S, 45  N].
#
# EXAMPLES
# ========
#
#
# To build OLR climatology :
# ::
#
#  $ cat_clim_olr.sh
#
# FILES
# =====
#
# original location
# ~~~~~~~~~~~~~~~~~
#
# /usr/home/fplod/incas/varamma/varamma_ws/src/cat_clim_olr.sh sur aedon.locean-ipsl.upmc.fr
#
# COMMENTS
# ========
#
#
# If yearmin and yearmax are the same one can compare input and output files
# like this:
#
#
# For yearmin=yearmax=2000
# ::
#
#  $ cdo diffv ${VARAMMA_ID}/olr.day.mean_2000_ng.nc \
#              ${VARAMMA_OD}/olr.day.mean_climato_ng.nc
#
#
# There must be a difference because 2000 is a leap year.
#
#
# For yearmin=yearmax=2001
# ::
#
#   $ cdo diffv ${VARAMMA_ID}/olr.day.mean_2001_ng.nc \
#               ${VARAMMA_OD}/olr.day.mean_climato_ng.nc
#
# There must be no difference on values of olr and info fields ++  vrifier
#
#
# SEE ALSO
# ========
#
# EVOLUTIONS
# ==========
#
# ++ unset
#
# ++ option debug/verbose
#
# ++ gestion log
#
# ++ vrification accs filein
#
# !! pb zeus et dedale signal  reseau le 200807
#
# $Id$
#
# - fplod 2008-08-05T09:37:14Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation from /homedata/eymard/scripts/script_cat_clim_AMSU
#
#-
#
# main program
system=$(uname)
case "${system}" in
AIX|IRIX64)
 echo " www : no specific posix checking"
;;
*)
 set -o posix
;;
esac
#
command=$(basename ${0})
log_date=$(date -u +"%Y-%m-%dT%H:%M:%SZ")
#
usage=" Usage : ${command}"
#
# ++ test si ncks available
#
yearmin=2000
yearmax=2007
#
yearmin=2000 # ++ pour debug
yearmax=2000 #++ pour debug
#
minargcount=0
if [ ${#} -lt ${minargcount} ]
then
 echo "eee : not enought arguments"
 echo "${usage}"
 exit 1
fi
#
while [ ! -z "${1}" ] # ++ pb bash
do
 case ${1} in
 -h)
    echo "${usage}"
 ;;
 *) # other choice
    echo "${usage}"
 ;;
 esac
 shift # next flag
done
#
set -u
#
# check for ${VARAMMA_LOG} definition
if [ "${VARAMMA_LOG}" = "" ]
then
 echo " eee : \${VARAMMA_LOG} not defined"
 exit 1
fi
#
# check for ${VARAMMA_LOG} existence
if [ ! -d ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not found"
 exit 1
fi
#
# check for permission access on VARAMMA_LOG
if [ ! -x ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not reachable"
 exit 1
fi
#
# check for write permission on VARAMMA_LOG
if [ ! -w ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not writable"
 exit 1
fi
#
log=${VARAMMA_LOG}/$(basename ${0} .sh).log.${log_date}
#++echo "runtime = ${log_date}" 1>> ${log}
#
# ++ VARAMMA_ID
# ++ VARAMMA_OD
#
# check for input files
listin=""
iyear=${yearmin}
while [ ${iyear} -le ${yearmax} ]
do
 cyear=$(echo ${iyear} | awk ' {printf "%4.4d",$0}')
 filein=${VARAMMA_ID}/olr.day.mean_${cyear}_ng.nc
 if [ ! -r ${VARAMMA_ID}/olr.day.mean.nc ]
 then
   echo "eee : ${filein} not accessible"
   exit 1
 fi
 file365[${iyear}]=${VARAMMA_OD}/olr.day.mean_${cyear}_365d_ng.nc
 file365_1=${VARAMMA_OD}/olr.day.mean_${cyear}_365d1_ng.nc
 file365_2=${VARAMMA_OD}/olr.day.mean_${cyear}_365d2_ng.nc
 # get rid of yyyy0229
 is_leap_year.sh ${iyear}
 ily_status=${?}
 if [ ${ily_status} -eq 0 ]
 then
  time1=$(echo ${iyear} | awk ' {printf "%4.4d-01-01 00:00:00.0",$1}')
  time2=$(echo ${iyear} | awk ' {printf "%4.4d-02-28 00:00:00.0",$1}') #++23:59
  time3=$(echo ${iyear} | awk ' {printf "%4.4d-03-01 00:00:00.0",$1}')
  time4=$(echo ${iyear} | awk ' {printf "%4.4d-12-31 00:00:00.0",$1}') #++23:59
  # cut first part of year
  ncks \
  --dimension time,"${time1}","${time2}" \
  ${filein} ${file365_1}
  status_ncks=${?}
  if [ ${status_ncks} -ne 0 ]
  then
   echo "eee : pb with ncks ${filein} between yyyy0101 and yyyy0228"
   exit 1
  fi
  # cut second part of year
  ncks \
  --dimension time,"${time3}","${time4}" \
  ${filein} ${file365_2}
  status_ncks=${?}
  if [ ${status_ncks} -ne 0 ]
  then
   echo "eee : pb with ncks ${filein} between yyyy0301 and yyyy1231"
   exit 1
  fi
  # join first and second part
  ncrcat ${file365_1} ${file365_2} ${file365[${iyear}]}
  status_ncrcat=${?}
  if [ ${status_ncrcat} -ne 0 ]
  then
   echo "eee : pb with ncrcat ${filein}"
   exit 1
  fi
 else
  cp ${filein} ${file365[${iyear}]}
 fi
 listin="${listin} ${file365[${iyear}]}"
 iyear=$(( ${iyear} + 1 ))
done
#
# build fileout
# based on the first file of the serie (ie yearmin)
fileout=${VARAMMA_OD}/$(basename ${file365[${yearmin}]} ${yearmin}_ng.nc)climato_ng.nc
if [ -f ${fileout} ]
then
  echo "eee : ${fileout} already exists"
  exit 1
fi
#
# ++ ncea ou ncra
ncea ${listin} ${fileout}_ncea
ncra ${listin} ${fileout}_ncra
status_ncks=${?}
if [ ${status_ncks} -ne 0 ]
then
  echo "eee : pb with ncks"
  exit 1
fi
#
# end
exit 0
