#!/bin/sh
#+
#
# NAME
# ====
#
# olr_split.sh - split OLR mean daily file
#
# SYNOPSYS
# ========
#
# ``olr_split.sh [-g] [-r] [-f] [-y year]``
#
# DESCRIPTION
# ===========
#
# Split OLR mean daily file by year and reduce geographical domain
# to [60  W, 50  E] [30  S, 45  N].
#
# If ``-g`` option is set, there will be no geographical domain reduction.
#
# If ``-f`` option is set, previously output files will be overwritten.
#
# If ``-r`` option is set, output files will be concatenated in one (might
# be usefull, combinated with ``-g`` option to check).
#
# If ``-y`` option is set with a year, only this year will be splitted.
#
# EXAMPLES
# ========
#
# To split ${VARAMMA_ID}/olr.day.mean.nc between [2000,2007] and between
# [60  W, 50  E] [30  S, 45  N]
# ::
#
#  $ olr_split.sh
#
# To split ${VARAMMA_ID}/olr.day.mean.nc in 2006 between
# [60  W, 50  E] [30  S, 45  N]
# ::
#
#  $ olr_split.sh -y 2006
#
# To split globaly and build a recomposed file
# ::
#
#  $ olr_split.sh -g -r
#
# one might compare original and rebuild file
# ::
#
#  $ cdo diffv ${VARAMMA_ID}/olr.day.mean.nc ${VARAMMA_OD}/olr.day.mean_rebuild.nc
#
# diff should only show differences in global attributes
#
# CAUTIONS
# ========
#
# Does'nt work on zeus because of UDUnits library problems
#
# ++++ GROS DOUTE SUR LES LONGITUDES DANS CES FICHIERS +++++++
#
# FILES
# =====
#
# original location
# ~~~~~~~~~~~~~~~~~
#
# /usr/home/fplod/incas/varamma/varamma_ws/olr_split.sh sur aedon.locean-ipsl.upmc.fr
#
#
# TODO
# ====
#
# ++ unset
#
# ++ option debug/verbose
#
# ++ gestion log
#
# ++ vrification accs filein
#
# ++ found none interactive actionof ncks if output file exists
#
# EVOLUTIONS
# ==========
#
#
# $Id$
#
# - fplod 2008-08-14T14:53:04Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * modify West longitude conversion according to
#     http://en.wikipedia.org/wiki/Longitude
# - fplod 2008-08-13T14:26:41Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add -f option
#   * add -y option
#   * add 180 degre to longitude centered on meridien 0 (<0 =W , >0=E)
#
# - fplod 2008-07-24T15:02:12Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
AIX|IRIX64)
 echo " www : no specific posix checking"
;;
*)
 set -o posix
;;
esac
#
case $(hostname) in
zeus.locean-ipsl.upmc.fr|dedale.locean-ipsl.upmc.fr)
 echo "eee : pb on UDUnits library on zeus"
 echo "eee : contact system team"
 exit 1
;;
esac
#
command=$(basename ${0})
log_date=$(date -u +"%Y-%m-%dT%H:%M:%SZ")
#
usage=" Usage : ${command} [-r] [-g] [-f]"
#
# ++ test si ncks available
#
# default
force=0
latmin=-30
latmax=45
lonmin=$((-60 + 360))
lonmax=50
global=0
yearmin=2000
yearmax=2007
rebuild=0
#
minargcount=0
if [ ${#} -lt ${minargcount} ]
then
 echo "eee : not enought arguments"
 echo "${usage}"
 exit 1
fi
#
while [ ! -z "${1}" ] # ++ pb bash
do
 case ${1} in
 -g)
    global=1
# ++ comment connaitre la 1er anne si -g.
# dans le README on nous dit que a commence en 1974 mais il faudrait automatiser
# ++ idem pour la dernire anne
# pour l'instant forage
  yearmin=1974
  yearmax=2008
  echo "www : forage yearmin yearmax : ${yearmin} ${yearmax}"
 ;;
 -f)
    force=1
 ;;
 -r)
    rebuild=1
 ;;
 -y)
    yearmin=${2}
    yearmax=${yearmin}
    shift
 ;;
 -h)
    echo "${usage}"
    exit 0
 ;;
 *) # other choice
    echo "${usage}"
    exit 1
 ;;
 esac
 shift # next flag
done
#
set -u
#
# ++ check validuty of yearmin and yearmax
#
# check for ${VARAMMA_LOG} definition
if [ "${VARAMMA_LOG}" = "" ]
then
 echo " eee : \${VARAMMA_LOG} not defined"
 exit 1
fi
#
# check for ${VARAMMA_LOG} existence
if [ ! -d ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not found"
 exit 1
fi
#
# check for permission access on VARAMMA_LOG
if [ ! -x ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not reachable"
 exit 1
fi
#
# check for write permission on VARAMMA_LOG
if [ ! -w ${VARAMMA_LOG} ]
then
 echo " eee : ${VARAMMA_LOG} not writable"
 exit 1
fi
#
log=${VARAMMA_LOG}/$(basename ${0} .sh).log.${log_date}
#++echo "command = $(basename ${0})" 1>>${log}
#++echo "runtime = ${log_date}" 1>> ${log}
#
# ++ VARAMMA_ID
# ++ VARAMMA_OD
#
# check for input file
filein=${VARAMMA_ID}/olr.day.mean.nc
if [ ! -r ${VARAMMA_ID}/olr.day.mean.nc ]
then
   echo "eee : ${filein} not accessible"
   exit 1
fi
#
# build date string for ncks command
list_split=""
iyear=${yearmin}
while [ ${iyear} -le ${yearmax} ]
do
 timemin=$(echo ${iyear} | awk ' {printf "%4.4d-01-01 00:00:00.0",$1}')
 timemax=$(echo ${iyear} | awk ' {printf "%4.4d-12-31 00:00:00.0",$1}') #++23:59:59
 echo "iii : extraction ${iyear} from ${filein}" # ++ voir seulement si debug demand
 if [ ${global} -eq 0 ]
 then
  fileout=${VARAMMA_OD}/$(basename ${filein} .nc)_${iyear}_ng.nc
 else
  fileout=${VARAMMA_OD}/$(basename ${filein} .nc)_${iyear}.nc
 fi
 if [ -f ${fileout} ]
 then
  if [ ${force} -eq 0 ]
  then
   echo "eee : ${fileout} already exists"
   exit 1
  else
   # I remove the file because I don't know how to tell ncks to ask interactivily if I want to append, overwrite etc...
   rm -f ${fileout}
  fi
 fi
 if [ ${global} -eq 0 ]
 then
    # build float representation of lat and long limit (for hyperslab)
    clatmin=$(echo ${latmin} | awk ' {printf "%+3.1f",$1}')
    clatmax=$(echo ${latmax} | awk ' {printf "%+3.1f",$1}')
    clonmin=$(echo ${lonmin} | awk ' {printf "%+4.1f",$1}')
    clonmax=$(echo ${lonmax} | awk ' {printf "%+4.1f",$1}')
    ncks \
    --dimension time,"${timemin}","${timemax}" \
    --dimension lat,"${clatmin}","${clatmax}" \
    --dimension lon,"${clonmin}","${clonmax}" \
    ${filein} ${fileout}
    status_ncks=${?}
    if [ ${status_ncks} -ne 0 ]
    then
       echo "eee : pb with ncks ${filein}"
       exit 1
    else
       list_split="${list_split} ${fileout}"
    fi
 else
    ncks \
    --dimension time,"${timemin}","${timemax}" \
    ${filein} ${fileout}
    status_ncks=${?}
    if [ ${status_ncks} -ne 0 ]
    then
       echo "eee : pb with ncks ${filein}"
       exit 1
    else
       list_split="${list_split} ${fileout}"
    fi
 fi
 iyear=$(( ${iyear} + 1 ))
done
#
echo "iii : list of splitted files : ${list_split}"
#
if [ ${rebuild} -eq 1 ]
then
# if rebuild is asked, concatenation of all the splitted files
   filetot=${VARAMMA_OD}/$(basename ${filein} .nc)_rebuild.nc
   rm -f  ${filetot} 2> /dev/null
   ncrcat ${list_split} ${filetot}
   status_ncrcat=${?}
   if [ ${status_ncrcat} -ne 0 ]
   then
      echo "eee : pb with ncrcat"
      exit 1
   else
      echo "iii : rebuild result in ${filetot}"
   fi
fi
#
# end
exit 0
